==> libavg_0.7.0.orig.tar.gz: libavg-0.7.0/src/base/Profiler.h <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2006 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#ifndef _Profiler_H_ 
#define _Profiler_H_

#include "ThreadProfiler.h"

#include <boost/thread.hpp>
#include <boost/thread/mutex.hpp>

#include <vector>

namespace avg {

class Profiler {
public:
    static Profiler& get();
    virtual ~Profiler();
 
    void dumpFrame();
    void dumpStatistics();

    // Interface to ThreadProfiler
    void registerThreadProfiler(ThreadProfilerPtr pThreadProfiler);
    ThreadProfilerPtr getThreadProfiler();

private:
    Profiler();

    typedef std::vector<ThreadProfilerPtr> ThreadProfilerArray;
    ThreadProfilerArray m_ThreadProfilers;
    boost::mutex m_Mutex;
};

}

#endif

==> libavg_0.8.0.orig.tar.gz: libavg-0.8.0/src/base/Profiler.h <==
//
//  libavg - Media Playback Engine. 
//  Copyright (C) 2003-2008 Ulrich von Zadow
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  Current versions can be found at www.libavg.de
//

#ifndef _Profiler_H_ 
#define _Profiler_H_

#include <boost/thread.hpp>
#include <boost/thread/mutex.hpp>
#include <boost/shared_ptr.hpp>

#include <vector>

namespace avg {

class ThreadProfiler;
typedef boost::shared_ptr<ThreadProfiler> ThreadProfilerPtr;

class Profiler {
public:
    static Profiler& get();
    virtual ~Profiler();
 
    void dumpFrame();
    void dumpStatistics();

    // Interface to ThreadProfiler
    void registerThreadProfiler(ThreadProfilerPtr pThreadProfiler);
    ThreadProfilerPtr getThreadProfiler();

private:
    Profiler();

    typedef std::vector<ThreadProfilerPtr> ThreadProfilerArray;
    ThreadProfilerArray m_ThreadProfilers;
    boost::mutex m_Mutex;
};

}

#endif
